# Nitroflare Uploader

A Python package to upload files to Nitroflare with a console-based upload progress bar.

## Installation

Install the package using `pip`:

```bash
pip install nitroflare_uploader
